Index: trunk/ippTools/src/warptool.c
===================================================================
--- trunk/ippTools/src/warptool.c	(revision 11983)
+++ trunk/ippTools/src/warptool.c	(revision 11985)
@@ -761,11 +761,11 @@
         " JOIN p4SkyCellMap\n"
         "   USING(p4_id)\n"
-        " LEFT JOIN p4Scfile\n"
+        " LEFT JOIN p4Skyfile\n"
         "   USING(p4_id, skycell_id, tess_id)\n"
         " WHERE\n"
         "   p4Run.state = 'run'\n" 
-        "   AND p4Scfile.p4_id IS NULL\n"
-        "   AND p4Scfile.skycell_id IS NULL\n"
-        "   AND p4Scfile.tess_id IS NULL\n"
+        "   AND p4Skyfile.p4_id IS NULL\n"
+        "   AND p4Skyfile.skycell_id IS NULL\n"
+        "   AND p4Skyfile.tess_id IS NULL\n"
     );
 
@@ -893,5 +893,5 @@
     }
 
     // we don't want to insert the last scfile in a run but then not mark the
     // run as 'stop'
     if (!psDBTransaction(config->dbh)) {
@@ -901,5 +901,5 @@
 
     // XXX need to validate that this coresponds to an p4InputImfile
-    if (!p4ScfileInsert(config->dbh, 
+    if (!p4SkyfileInsert(config->dbh, 
             (psS32)atoi(p4_id),
             skycell_id,
@@ -949,9 +949,9 @@
         "           p4Run.p4_id,\n"
         "           p4SkyCellMap.p4_id as foo,\n"
-        "           p4Scfile.p4_id as bar\n"
+        "           p4Skyfile.p4_id as bar\n"
         "       FROM p4Run\n"
         "       JOIN p4SkyCellMap\n"
         "           USING(p4_id)\n"
-        "       LEFT JOIN p4Scfile\n"
+        "       LEFT JOIN p4Skyfile\n"
         "           USING(p4_id, skycell_id, tess_id)\n"
         "       WHERE\n"
@@ -960,5 +960,5 @@
         "           p4Run.p4_id\n"  
         "       HAVING\n"
-        "       COUNT(p4SkyCellMap.p4_id) = COUNT(p4Scfile.p4_id)\n"
+        "       COUNT(p4SkyCellMap.p4_id) = COUNT(p4Skyfile.p4_id)\n"
         "       ) as Foo\n"
         "   )\n"
@@ -990,7 +990,7 @@
     psString query = psStringCopy( 
         "SELECT\n"
-        "   p4Scfile.*\n"
+        "   p4Skyfile.*\n"
         " FROM p4Run\n"
-        " JOIN p4Scfile\n"
+        " JOIN p4Skyfile\n"
         "   USING(p4_id)\n"
         " WHERE\n"
@@ -999,5 +999,5 @@
 
     if (config->where) {
-        psString whereClause = psDBGenerateWhereConditionSQL(config->where, "p4Scfile");
+        psString whereClause = psDBGenerateWhereConditionSQL(config->where, "p4Skyfile");
         psStringAppend(&query, " AND %s", whereClause);
         psFree(whereClause);
@@ -1033,5 +1033,5 @@
     }
     if (!psArrayLength(output)) {
-        psError(PS_ERR_UNKNOWN, false, "no p4Scfile rows found");
+        psError(PS_ERR_UNKNOWN, false, "no p4Skyfile rows found");
         psFree(output);
         return true;
@@ -1050,5 +1050,5 @@
     if (psArrayLength(output)) {
         // negative simple so the default is true
-        if (!ippdbPrintMetadatas(stdout, output, "p4Scfile", !simple)) {
+        if (!ippdbPrintMetadatas(stdout, output, "p4Skyfile", !simple)) {
             psError(PS_ERR_UNKNOWN, false, "failed to print array");
             psFree(output);
@@ -893,5 +893,5 @@
     }
 
-    // we don't want to insert the last scfile in a run but then not mark the
+    // we don't want to insert the last skyfile in a run but then not mark the
     // run as 'stop'
     if (!psDBTransaction(config->dbh)) {
